@@ -51,35 +51,59 @@ def run_pulls(**kwargs):
 @click.option('-i', '--inputdir', required=True, help='Path to directory containing pull results')
 @click.option('-p', '--poi', default=None, help='Parameter of interest for plotting impact')
 @click.option('-n', '--n_rank', type=int, default=None, help='Total number of NP to rank')
-@click.option('-m', '--rank_per_plot', type=int, default=20, help='Number of NP to show in a single plot')
-@click.option('--ranking/--no_ranking', default=True, help='Rank NP by impact')
-@click.option('--threshold', type=float, default=0., help='Filter NP by postfit impact threshold')
-@click.option('--show_sigma/--hide_sigma', default=True, help='Show one standard deviation pull')
-@click.option('--show_prefit/--hide_prefit', default=True, help='Show prefit impact')
-@click.option('--show_postfit/--hide_postfit', default=True, help='Show postfit impact')
-@click.option('--sigma_bands/--no_sigma_bands', default=False, help='Draw +-1, +-2 sigma bands')
-@click.option('--sigma_lines/--no_sigma_lines', default=True, help='Draw +-1 sigma lines')
-@click.option('--shade/--no_shade', default=True, help='Draw shade')
-@click.option('--correlation/--no_correlation', default=True, help='Show correlation impact')
-@click.option('--onesided/--overlap', default=True, help='Show onesided impact')
-@click.option('--theta_max', type=float, default=2, help='Pull range')
-@click.option('-y', '--padding', type=int, default=7, help='Padding below plot for texts and legends.' +\
-                                                           'NP column height is 1 unit.')
-@click.option('-h', '--height', type=float, default=1.0, help='NP column height')
-@click.option('-s', '--spacing', type=float, default=0., help='Spacing between impact box')
-@click.option('-d', '--display_poi', default=r"$\mu$", help='POI name to be shown in the plot')
+@click.option('-m', '--rank_per_plot', type=int, default=20, show_default=True,
+              help='Number of NP to show in a single plot')
+@click.option('--ranking/--no_ranking', default=True, show_default=True,
+              help='Rank NP by impact')
+@click.option('--threshold', type=float, default=0., show_default=True,
+              help='Filter NP by postfit impact threshold')
+@click.option('--show_sigma/--hide_sigma', default=True, show_default=True,
+              help='Show one standard deviation pull')
+@click.option('--show_prefit/--hide_prefit', default=True, show_default=True,
+              help='Show prefit impact')
+@click.option('--show_postfit/--hide_postfit', default=True, show_default=True,
+              help='Show postfit impact')
+@click.option('--sigma_bands/--no_sigma_bands', default=False, show_default=True,
+              help='Draw +-1, +-2 sigma bands')
+@click.option('--sigma_lines/--no_sigma_lines', default=True, show_default=True,
+              help='Draw +-1 sigma lines')
+@click.option('--shade/--no_shade', default=True, show_default=True,
+              help='Draw shade')
+@click.option('--correlation/--no_correlation', default=True, show_default=True,
+              help='Show correlation impact')
+@click.option('--onesided/--overlap', default=True, show_default=True,
+              help='Show onesided impact')
+@click.option('--relative/--absolute', default=False, show_default=True,
+              help='Show relative variation')
+@click.option('--theta_max', type=float, default=2, show_default=True,
+              help='Pull range')
+@click.option('-y', '--padding', type=int, default=7, show_default=True,
+              help='Padding below plot for texts and legends. NP column height is 1 unit.')
+@click.option('-h', '--height', type=float, default=1.0, show_default=True,
+              help='NP column height')
+@click.option('-s', '--spacing', type=float, default=0., show_default=True,
+              help='Spacing between impact box')
+@click.option('-d', '--display_poi', default=r"$\mu$", show_default=True,
+              help='POI name to be shown in the plot')
 @click.option('-t', '--extra_text', default=None, help='Extra texts below the ATLAS label. '+\
                                                        'Use "//" as newline delimiter')
-@click.option('--elumi_label/--no_elumi_label', default=True, help='Show energy and luminosity labels')
-@click.option('--ranking_label/--no_ranking_label', default=True, help='Show ranking label')
-@click.option('--energy', type=float, default=13, help='Beam energy')
-@click.option('--lumi', type=float, default=139, help='Luminosity')
-@click.option('--combine_pdf/--split_pdf', default=True, help='Combine all ranking plots into a single pdf')
-@click.option('--outdir', default='ranking_plots', help='Output directory')
-@click.option('-o', '--outname', default='ranking', help='Output file name prefix')
-@click.option('--style', default='default', help='Plotting style. Built-in styles are "default" and "trex".'+\
-                                                 'Specify path to yaml file to set custom plotting style.')
-@click.option('--fix_axis_scale/--free_axis_scale', default=True, help='Fix the axis scale across all ranking plots')
+@click.option('--elumi_label/--no_elumi_label', default=True, show_default=True,
+              help='Show energy and luminosity labels')
+@click.option('--ranking_label/--no_ranking_label', default=True, show_default=True,
+              help='Show ranking label')
+@click.option('--energy', type=float, default=13, show_default=True, help='Beam energy')
+@click.option('--lumi', type=float, default=139, show_default=True, help='Luminosity')
+@click.option('--combine_pdf/--split_pdf', default=True, show_default=True,
+              help='Combine all ranking plots into a single pdf')
+@click.option('--outdir', default='ranking_plots', show_default=True,
+              help='Output directory')
+@click.option('-o', '--outname', default='ranking', show_default=True,
+              help='Output file name prefix')
+@click.option('--style', default='default', show_default=True,
+              help='Plotting style. Built-in styles are "default" and "trex".'+\
+                   'Specify path to yaml file to set custom plotting style.')
+@click.option('--fix_axis_scale/--free_axis_scale', default=True, show_default=True,
+              help='Fix the axis scale across all ranking plots')
 def plot_pulls(**kwargs):
     """
     Tool for plotting NP pulls and impact rankings
@@ -230,7 +254,7 @@ def harmonize_np(ws_files, reference, input_config_path, base_path, outfile):
               help='Match the values of nuisance parameters and the corresponding global '
                    'observables when generating the asimov data. This is important for making '
                    'sure the asimov data has the (conditional) minimal NLL.')
-@click.option('--conditional_mle/--undonditional_mle', default=True, show_default=True,
+@click.option('--conditional_mle/--unconditional_mle', default=True, show_default=True,
               help='Perform conditional maximum likelihood estimation. This option is effective '
                    'only if poi_profile is specified. If True, best-fit values are obtained for '
                    'mu = poi_profile. If False, the overal best-fit values are obtained.')
