@@ -8,7 +8,7 @@ class AnalysisObject(object):
                  fix_param:str='', profile_param:str='', ws_name:Optional[str]=None, 
                  mc_name:Optional[str]=None, snapshot_name:Optional[str]=None,
                  minimizer_type:str='Minuit2', minimizer_algo:str='Migrad', precision:float=0.001, 
-                 eps:float=1.0, strategy:int=0, print_level:int=1, timer:bool=True,
+                 eps:float=1.0, strategy:int=1, print_level:int=-1, timer:bool=True,
                  num_cpu:int=1, offset:bool=True, optimize:int=2, eigen:bool=False,
                  fix_cache:bool=True, fix_multi:bool=True, max_calls:int=-1, 
                  max_iters:int=-1, constrain_nuis:bool=True, batch_mode:bool=False,
@@ -61,7 +61,7 @@ class AnalysisObject(object):
             nll_commands.append(ROOT.RooFit.BatchMode(batch_mode))
         if hasattr(ROOT.RooFit, "IntegrateBins"):
             nll_commands.append(ROOT.RooFit.IntegrateBins(int_bin_precision))          
-        minimize_options = {
+        minimizer_options = {
             'minimizer_type'   : minimizer_type,
             'minimizer_algo'   : minimizer_algo,
             'default_strategy' : strategy,
@@ -75,6 +75,8 @@ class AnalysisObject(object):
             'timer'            : timer
         }
 
-        minimizer.configure(nll_commands=nll_commands, **minimize_options)
+        minimizer.configure(nll_commands=nll_commands, **minimizer_options)
         
-        self.minimizer = minimizer
\ No newline at end of file
+        self.minimizer = minimizer
+        self.minimizer_options = minimizer_options
+        self.nll_commands     = nll_commands        
\ No newline at end of file
