@@ -7,6 +7,11 @@ def pretty_float(val:float)->Union[int, float]:
         return int(val)
     return val
 
+def pretty_value(val:Union[int, float])->Union[int, float]:
+    if isinstance(val, float) and val.is_integer():
+        return int(val)
+    return val
+
 def is_integer(s:str):
     if not s:
         return False
