@@ -341,7 +341,7 @@ class NPRankingPlot:
         
     @staticmethod
     def plot_impact(axis, data, show_prefit:bool=True, show_postfit:bool=True, correlation:bool=True, onesided:bool=True, 
-                    height:float=1.0, spacing:float=0., **styles):
+                    relative:bool=False, height:float=1.0, spacing:float=0., **styles):
         n = len(data)  
         impact_types = []
         if show_postfit:
@@ -353,8 +353,12 @@ class NPRankingPlot:
         for it in impact_types:
             prefix = 'impact_{}'.format(it)
             # retrieve the impact data
-            impact_down = data['{}_down'.format(prefix)].values
-            impact_up = data['{}_up'.format(prefix)].values
+            if relative:
+                impact_down = data['{}_down'.format(prefix)].values / data['poi_hat'].values
+                impact_up = data['{}_up'.format(prefix)].values / data['poi_hat'].values           
+            else:
+                impact_down = data['{}_down'.format(prefix)].values
+                impact_up = data['{}_up'.format(prefix)].values
 
             if correlation:
                 # negative-valued correlated impact 
@@ -468,10 +472,10 @@ class NPRankingPlot:
     
     @staticmethod
     def _plot(data, show_sigma:bool=True, show_prefit:bool=True, show_postfit:bool=True, sigma_bands:bool=False,
-              sigma_lines:bool=True, shade:bool=True, correlation:bool=True, onesided:bool=True, theta_max:float=2, 
-              padding:int=7, height:float=1, spacing:float=0, display_poi:str=r"$\mu$", extra_text:str=None, 
-              elumi_label:bool=True, ranking_label:bool=True, energy:float=13, lumi:float=139, r_start:int=1,
-              style:Dict=DEFAULT_STYLE):
+              sigma_lines:bool=True, shade:bool=True, correlation:bool=True, onesided:bool=True, relative:bool=False,
+              theta_max:float=2, padding:int=7, height:float=1, spacing:float=0, display_poi:str=r"$\mu$", 
+              extra_text:str=None, elumi_label:bool=True, ranking_label:bool=True, energy:float=13, lumi:float=139, 
+              r_start:int=1, style:Dict=DEFAULT_STYLE):
         # setup figure and axes
         plt.clf()
         fig_width, fig_height = style['figure']['width'], style['figure']['height']
@@ -481,13 +485,17 @@ class NPRankingPlot:
         NPRankingPlot.setup_axis(ax1, ax2, **style)
         ax1.set_xlim((-theta_max, theta_max))
         ax1.set_xlabel(r"$(\hat{\theta}-\theta_0)/\Delta\theta$" , **style['xaxis_label'])
-        ax2.set_xlabel(r"$\Delta$ "+display_poi , **style['xaxis_label'], labelpad=10)
+        if relative:
+            ax2.set_xlabel(r"$\Delta$ " + display_poi +"/" + display_poi, 
+                           **style['xaxis_label'], labelpad=10)
+        else:
+            ax2.set_xlabel(r"$\Delta$ " + display_poi , **style['xaxis_label'], labelpad=10)
         if sigma_bands:
             shade, show_prefit, show_postfit = False, False, False            
         n = len(data)
         NPRankingPlot.plot_impact(ax2, data, show_prefit=show_prefit, show_postfit=show_postfit,
-                                  correlation=correlation, onesided=onesided, height=height, 
-                                  spacing=spacing, **style)
+                                  correlation=correlation, onesided=onesided, relative=relative,
+                                  height=height, spacing=spacing, **style)
         centralize_axis(ax2, 'x')
         if shade:
             draw_hatches(ax2, n, height=height, **style['shade'])
@@ -497,8 +505,8 @@ class NPRankingPlot:
         if sigma_lines:
             draw_sigma_lines(ax1, n, height=height, **style['sigma_lines'])
         NPRankingPlot.draw_np_labels(ax2, data, padding=padding, height=height)
-        format_axis_ticks(ax1, y_axis=False)
-        format_axis_ticks(ax2, y_axis=False)
+        format_axis_ticks(ax1, y_axis=False, x_axis_styles=style['xaxis'])
+        format_axis_ticks(ax2, y_axis=False, x_axis_styles=style['xaxis'])
         NPRankingPlot.draw_labels(ax1, extra_text=extra_text, height=height, elumi_label=elumi_label,
                                   ranking_label=ranking_label, energy=energy, lumi=lumi, 
                                   r_start=r_start, r_end=r_start + n - 1, **style)
@@ -508,11 +516,11 @@ class NPRankingPlot:
         return fig
     
     def plot(self, show_sigma:bool=True, show_prefit:bool=True, show_postfit:bool=True, sigma_bands:bool=False,
-              sigma_lines:bool=True, shade:bool=True, correlation:bool=True, onesided:bool=True, theta_max:float=2, 
-              padding:int=7, height:float=1, spacing:float=0, display_poi:str=r"$\mu$", extra_text:str=None, 
-              elumi_label:bool=True, ranking_label:bool=True, energy:float=13, lumi:float=139,
-              n_rank=None, rank_per_plot=20, combine_pdf=True, threshold=0, ranking=True, fix_axis_scale=True,
-              outdir="ranking_plots", outname:str='ranking', style:Union[str, Dict]=DEFAULT_STYLE):
+             sigma_lines:bool=True, shade:bool=True, correlation:bool=True, onesided:bool=True, relative:bool=False,
+             theta_max:float=2, padding:int=7, height:float=1, spacing:float=0, display_poi:str=r"$\mu$", 
+             extra_text:str=None, elumi_label:bool=True, ranking_label:bool=True, energy:float=13, lumi:float=139,
+             n_rank=None, rank_per_plot=20, combine_pdf=True, threshold=0, ranking=True, fix_axis_scale=True,
+             outdir="ranking_plots", outname:str='ranking', style:Union[str, Dict]=DEFAULT_STYLE):
         if isinstance(style, str):
             style = self.parse_style(style)
         if self.data is None:
@@ -537,8 +545,8 @@ class NPRankingPlot:
             data_slice = processed_data[::-1][start:end][::-1]
             fig = self._plot(data_slice, show_sigma=show_sigma, show_prefit=show_prefit, show_postfit=show_postfit, 
                              sigma_bands=sigma_bands, sigma_lines=sigma_lines, shade=shade, correlation=correlation,
-                             onesided=onesided, theta_max=theta_max, padding=padding, height=height, spacing=spacing,
-                             display_poi=display_poi, extra_text=extra_text, elumi_label=elumi_label,
+                             onesided=onesided, relative=relative, theta_max=theta_max, padding=padding, height=height, 
+                             spacing=spacing, display_poi=display_poi, extra_text=extra_text, elumi_label=elumi_label,
                              ranking_label=ranking_label, energy=energy, lumi=lumi, r_start=start+1, style=style)
             if fix_axis_scale:
                 if nominal_xlim is None:
