@@ -25,21 +25,27 @@ def suggest_markersize(nbins:int):
     return 1
 
 def format_axis_ticks(ax, x_axis=True, y_axis=True, major_length=16, minor_length=8,
-                      width=1, labelsize=5):
+                      width=1, labelsize=None, x_axis_styles=None, y_axis_styles=None):
     if x_axis:
         if ax.get_xaxis().get_scale() != 'log':
             ax.xaxis.set_minor_locator(AutoMinorLocator())
+        styles = {"labelsize":labelsize}
+        if x_axis_styles is not None:
+            styles.update(x_axis_styles)
         ax.tick_params(axis="x", which="major", direction='in', length=major_length,
-                       width=width, labelsize=labelsize)
+                       width=width, **styles)
         ax.tick_params(axis="x", which="minor", direction='in', length=minor_length,
-                       width=width, labelsize=labelsize)
+                       width=width, **styles)
     if y_axis:
         if ax.get_yaxis().get_scale() != 'log':
-            ax.yaxis.set_minor_locator(AutoMinorLocator())        
+            ax.yaxis.set_minor_locator(AutoMinorLocator())    
+        styles = {"labelsize":labelsize}
+        if y_axis_styles is not None:
+            styles.update(y_axis_styles)
         ax.tick_params(axis="y", which="major", direction='in', length=major_length,
-                       width=width, labelsize=labelsize)
+                       width=width, **styles)
         ax.tick_params(axis="y", which="minor", direction='in', length=minor_length,
-                       width=width, labelsize=labelsize)
+                       width=width, **styles)
     for axis in ['top','bottom','left','right']:
         ax.spines[axis].set_linewidth(width)
 
