@@ -1,15 +1,16 @@
+import os
 import sys
 import time
+import json
 import datetime
 import functools
-import multiprocessing
 from concurrent.futures  import ProcessPoolExecutor
 
 def timely_info(green_text, normal_text, adjust=40):
     print(datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S'), '\033[92m[INFO]\033[0m', '\033[92m{}\033[0m'.format(green_text).rjust(40, ' '), normal_text)
 
 def get_cpu_count():
-    return multiprocessing.cpu_count()
+    return os.cpu_count()
 
 def parallel_run(func, *iterables, max_workers):
 
@@ -18,6 +19,19 @@ def parallel_run(func, *iterables, max_workers):
 
     return [i for i in result]
 
+def execute_multi_tasks(func, *iterables, parallel):
+    if parallel == 0:
+        result = []
+        for args in zip(*iterables):
+            result.append(func(*args))
+        return result
+    else:
+        if parallel == -1:
+            max_workers = get_cpu_count()
+        else:
+            max_workers = parallel
+        return parallel_run(func, *iterables, max_workers=max_workers)
+
 
 def timer(func):
     """Print the runtime of the decorated function"""
@@ -62,4 +76,11 @@ def redirect_stdout_test(func):
             return value
         else:
             return func(*args, **kwargs)
-    return wrapper_timer
\ No newline at end of file
+    return wrapper_timer
+
+def json_load(fp, *args, **kwargs):
+    try:
+        data = json.load(fp, *args, **kwargs)
+    except:
+        raise RuntimeError(f"broken json input: {fp}")
+    return data
\ No newline at end of file
